@@ -25,9 +25,9 @@ import (
 	"github.com/prometheus/common/expfmt"
 	"github.com/prometheus/prometheus/prompb"
 
-	"github.com/open-cluster-management/metrics-collector/pkg/logger"
-	"github.com/open-cluster-management/metrics-collector/pkg/reader"
-	"github.com/open-cluster-management/metrics-collector/pkg/utils"
+	"github.com/stolostron/metrics-collector/pkg/logger"
+	"github.com/stolostron/metrics-collector/pkg/reader"
+	"github.com/stolostron/metrics-collector/pkg/utils"
 )
 
 const (
